@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package Opsview::RestAPI::Exception;
-$Opsview::RestAPI::Exception::VERSION = '1.181000';
+$Opsview::RestAPI::Exception::VERSION = '1.190220';
 # ABSTRACT: Opsview::RestAPI Exception object
 
 
@@ -17,19 +17,28 @@ use overload
 sub new {
     my ( $class, %args ) = @_;
 
-    my @caller_keys
-        = (
-        qw/ package filename line subroutine hasargs wantarray evaltext is_require hints bitmask hinthash /
-        );
+    my @caller_keys = (
+        qw/ package filename line subroutine hasargs wantarray evaltext is_require / 
+    );
+    #hints bitmask hinthash /
 
-    bless { %args, map { $caller_keys[$_] => ( caller(0) )[$_] } ( 0 .. 10 ), }, $class;
+    # Build up the callstack to a max of 7 levels
+    my $i=0;
+    do {
+        my @caller = (caller($i++));
+        return unless(@caller);
+
+        push( @{ $args{callstack} }, { map { $caller_keys[$_] => $caller[$_] } ( 0 .. $#caller_keys) } );
+    } while ( $i < 7 );
+
+    bless { %args }, $class;
 }
 
 
-sub line     { $_[0]->{line} }
-sub path     { $_[0]->{filename} }
-sub filename { $_[0]->{filename} }
-sub package  { $_[0]->{package} }
+sub line     { $_[0]->{callstack}[0]{line} }
+sub path     { $_[0]->{callstack}[0]{filename} }
+sub filename { $_[0]->{callstack}[0]{filename} }
+sub package  { $_[0]->{callstack}[0]{package} }
 
 
 sub message {
@@ -63,7 +72,7 @@ Opsview::RestAPI::Exception - Opsview::RestAPI Exception object
 
 =head1 VERSION
 
-version 1.181000
+version 1.190220
 
 =head1 SYNOPSIS
 
